# NeuFlow

## Original code

[https://github.com/neufieldrobotics/NeuFlow](https://github.com/neufieldrobotics/NeuFlow)

## Code license

See [LICENSE](LICENSE).

## Pretrained weights license

Not specified.

## Citation

```
@Article{Zhang2024NeuFlowRealtime,
  author  = {Zhiyong Zhang and Huaizu Jiang and Hanumant Singh},
  journal = {ArXiv},
  title   = {{NeuFlow}: Real-time, High-accuracy Optical Flow Estimation on Robots Using Edge Devices},
  year    = {2024},
}

```